==> colourvalues_0.2.2.tar.gz: colourvalues/inst/include/colourvalues/palettes/topo.hpp <==
#ifndef R_COLOURVALUES_TOPO_H
#define R_COLOURVALUES_TOPO_H

#include <Rcpp.h>
using namespace Rcpp;

namespace colourvalues {
namespace palette {

  const Rcpp::NumericVector topo_red = {
    0.298039215686275,0.286274509803922,0.270588235294118,0.258823529411765,
    0.243137254901961,0.231372549019608,0.215686274509804,0.2,
    0.188235294117647,0.172549019607843,0.156862745098039,0.145098039215686,
    0.129411764705882,0.117647058823529,0.101960784313725,0.0862745098039216,
    0.0745098039215686,0.0588235294117647,0.0470588235294118,0.0313725490196078,
    0.0156862745098039,0.00392156862745098,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0.0156862745098039,0.0274509803921569,0.0431372549019608,0.0588235294117647,
    0.0705882352941176,0.0862745098039216,0.101960784313725,0.113725490196078,
    0.129411764705882,0.141176470588235,0.156862745098039,0.172549019607843,
    0.184313725490196,0.2,0.215686274509804,0.227450980392157,
    0.243137254901961,0.258823529411765,0.270588235294118,0.286274509803922,
    0.301960784313725,0.313725490196078,0.329411764705882,0.341176470588235,
    0.356862745098039,0.372549019607843,0.384313725490196,0.4,
    0.415686274509804,0.427450980392157,0.443137254901961,0.458823529411765,
    0.470588235294118,0.486274509803922,0.501960784313725,0.513725490196078,
    0.529411764705882,0.541176470588235,0.556862745098039,0.572549019607843,
    0.584313725490196,0.6,0.615686274509804,0.627450980392157,
    0.643137254901961,0.658823529411765,0.670588235294118,0.686274509803922,
    0.701960784313725,0.713725490196078,0.729411764705882,0.741176470588235,
    0.756862745098039,0.772549019607843,0.784313725490196,0.8,
    0.815686274509804,0.827450980392157,0.843137254901961,0.858823529411765,
    0.870588235294118,0.886274509803922,0.901960784313726,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1
  };

  const Rcpp::NumericVector topo_green = {
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0.0117647058823529,0.0235294117647059,
    0.0392156862745098,0.0509803921568627,0.0666666666666667,0.0823529411764706,
    0.0941176470588235,0.109803921568627,0.12156862745098,0.137254901960784,
    0.152941176470588,0.164705882352941,0.180392156862745,0.192156862745098,
    0.207843137254902,0.223529411764706,0.235294117647059,0.250980392156863,
    0.262745098039216,0.27843137254902,0.294117647058824,0.305882352941176,
    0.32156862745098,0.333333333333333,0.349019607843137,0.364705882352941,
    0.376470588235294,0.392156862745098,0.403921568627451,0.419607843137255,
    0.435294117647059,0.447058823529412,0.462745098039216,0.47843137254902,
    0.490196078431373,0.505882352941176,0.517647058823529,0.533333333333333,
    0.545098039215686,0.56078431372549,0.576470588235294,0.588235294117647,
    0.603921568627451,0.619607843137255,0.631372549019608,0.647058823529412,
    0.658823529411765,0.674509803921569,0.686274509803922,0.701960784313725,
    0.717647058823529,0.729411764705882,0.745098039215686,0.756862745098039,
    0.772549019607843,0.788235294117647,0.8,0.815686274509804,
    0.827450980392157,0.843137254901961,0.858823529411765,0.870588235294118,
    0.886274509803922,0.898039215686275,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    0.996078431372549,0.992156862745098,0.984313725490196,0.980392156862745,
    0.976470588235294,0.972549019607843,0.968627450980392,0.964705882352941,
    0.96078431372549,0.956862745098039,0.952941176470588,0.949019607843137,
    0.945098039215686,0.941176470588235,0.937254901960784,0.933333333333333,
    0.929411764705882,0.925490196078431,0.925490196078431,0.92156862745098,
    0.917647058823529,0.913725490196078,0.909803921568627,0.909803921568627,
    0.905882352941176,0.901960784313726,0.901960784313726,0.898039215686275,
    0.894117647058824,0.894117647058824,0.890196078431372,0.890196078431372,
    0.886274509803922,0.882352941176471,0.882352941176471,0.87843137254902,
    0.87843137254902,0.874509803921569,0.874509803921569,0.874509803921569,
    0.870588235294118,0.870588235294118,0.866666666666667,0.866666666666667,
    0.866666666666667,0.866666666666667,0.862745098039216,0.862745098039216,
    0.862745098039216,0.862745098039216,0.858823529411765,0.858823529411765,
    0.858823529411765,0.858823529411765,0.858823529411765,0.858823529411765,
    0.858823529411765,0.858823529411765,0.858823529411765,0.858823529411765,
    0.858823529411765,0.858823529411765,0.858823529411765,0.858823529411765,
    0.858823529411765,0.858823529411765,0.858823529411765,0.858823529411765,
    0.858823529411765,0.862745098039216,0.862745098039216,0.862745098039216,
    0.862745098039216,0.866666666666667,0.866666666666667,0.866666666666667,
    0.866666666666667,0.870588235294118,0.870588235294118,0.874509803921569,
    0.874509803921569,0.874509803921569,0.87843137254902,0.87843137254902
  };

  const Rcpp::NumericVector topo_blue = {
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,0.301960784313725,0.286274509803922,
    0.270588235294118,0.258823529411765,0.243137254901961,0.227450980392157,
    0.215686274509804,0.2,0.184313725490196,0.172549019607843,
    0.156862745098039,0.141176470588235,0.129411764705882,0.113725490196078,
    0.101960784313725,0.0862745098039216,0.0705882352941176,0.0588235294117647,
    0.0431372549019608,0.0274509803921569,0.0156862745098039,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0.00784313725490196,0.0156862745098039,0.0235294117647059,0.0313725490196078,
    0.0431372549019608,0.0509803921568627,0.0588235294117647,0.0666666666666667,
    0.0745098039215686,0.0823529411764706,0.0901960784313725,0.0980392156862745,
    0.109803921568627,0.117647058823529,0.125490196078431,0.133333333333333,
    0.141176470588235,0.149019607843137,0.156862745098039,0.164705882352941,
    0.176470588235294,0.184313725490196,0.192156862745098,0.2,
    0.207843137254902,0.215686274509804,0.223529411764706,0.235294117647059,
    0.243137254901961,0.250980392156863,0.258823529411765,0.266666666666667,
    0.274509803921569,0.282352941176471,0.290196078431373,0.301960784313725,
    0.309803921568627,0.317647058823529,0.325490196078431,0.333333333333333,
    0.341176470588235,0.349019607843137,0.356862745098039,0.368627450980392,
    0.376470588235294,0.384313725490196,0.392156862745098,0.4,
    0.407843137254902,0.415686274509804,0.423529411764706,0.435294117647059,
    0.443137254901961,0.450980392156863,0.458823529411765,0.466666666666667,
    0.474509803921569,0.482352941176471,0.490196078431373,0.501960784313725,
    0.509803921568627,0.517647058823529,0.525490196078431,0.533333333333333,
    0.541176470588235,0.549019607843137,0.556862745098039,0.568627450980392,
    0.576470588235294,0.584313725490196,0.592156862745098,0.6,
    0.607843137254902,0.615686274509804,0.623529411764706,0.635294117647059,
    0.643137254901961,0.650980392156863,0.658823529411765,0.666666666666667,
    0.674509803921569,0.682352941176471,0.690196078431373,0.701960784313725
  };

const Rcpp::List topo = Rcpp::List::create(
  _["r"] = topo_red,
  _["g"] = topo_green,
  _["b"] = topo_blue
);
} // namespace palette
} // namepsace colourvalues

#endif

==> colourvalues_0.3.9.tar.gz: colourvalues/inst/include/colourvalues/palettes/topo.hpp <==
#ifndef R_COLOURVALUES_TOPO_H
#define R_COLOURVALUES_TOPO_H

#include <Rcpp.h>
using namespace Rcpp;

namespace colourvalues {
namespace palette {

  const Rcpp::NumericVector topo_red = {
    0.298039215686275,0.286274509803922,0.270588235294118,0.258823529411765,
    0.243137254901961,0.231372549019608,0.215686274509804,0.2,
    0.188235294117647,0.172549019607843,0.156862745098039,0.145098039215686,
    0.129411764705882,0.117647058823529,0.101960784313725,0.0862745098039216,
    0.0745098039215686,0.0588235294117647,0.0470588235294118,0.0313725490196078,
    0.0156862745098039,0.00392156862745098,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0.0156862745098039,0.0274509803921569,0.0431372549019608,0.0588235294117647,
    0.0705882352941176,0.0862745098039216,0.101960784313725,0.113725490196078,
    0.129411764705882,0.141176470588235,0.156862745098039,0.172549019607843,
    0.184313725490196,0.2,0.215686274509804,0.227450980392157,
    0.243137254901961,0.258823529411765,0.270588235294118,0.286274509803922,
    0.301960784313725,0.313725490196078,0.329411764705882,0.341176470588235,
    0.356862745098039,0.372549019607843,0.384313725490196,0.4,
    0.415686274509804,0.427450980392157,0.443137254901961,0.458823529411765,
    0.470588235294118,0.486274509803922,0.501960784313725,0.513725490196078,
    0.529411764705882,0.541176470588235,0.556862745098039,0.572549019607843,
    0.584313725490196,0.6,0.615686274509804,0.627450980392157,
    0.643137254901961,0.658823529411765,0.670588235294118,0.686274509803922,
    0.701960784313725,0.713725490196078,0.729411764705882,0.741176470588235,
    0.756862745098039,0.772549019607843,0.784313725490196,0.8,
    0.815686274509804,0.827450980392157,0.843137254901961,0.858823529411765,
    0.870588235294118,0.886274509803922,0.901960784313726,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1
  };

  const Rcpp::NumericVector topo_green = {
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0.0117647058823529,0.0235294117647059,
    0.0392156862745098,0.0509803921568627,0.0666666666666667,0.0823529411764706,
    0.0941176470588235,0.109803921568627,0.12156862745098,0.137254901960784,
    0.152941176470588,0.164705882352941,0.180392156862745,0.192156862745098,
    0.207843137254902,0.223529411764706,0.235294117647059,0.250980392156863,
    0.262745098039216,0.27843137254902,0.294117647058824,0.305882352941176,
    0.32156862745098,0.333333333333333,0.349019607843137,0.364705882352941,
    0.376470588235294,0.392156862745098,0.403921568627451,0.419607843137255,
    0.435294117647059,0.447058823529412,0.462745098039216,0.47843137254902,
    0.490196078431373,0.505882352941176,0.517647058823529,0.533333333333333,
    0.545098039215686,0.56078431372549,0.576470588235294,0.588235294117647,
    0.603921568627451,0.619607843137255,0.631372549019608,0.647058823529412,
    0.658823529411765,0.674509803921569,0.686274509803922,0.701960784313725,
    0.717647058823529,0.729411764705882,0.745098039215686,0.756862745098039,
    0.772549019607843,0.788235294117647,0.8,0.815686274509804,
    0.827450980392157,0.843137254901961,0.858823529411765,0.870588235294118,
    0.886274509803922,0.898039215686275,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    0.996078431372549,0.992156862745098,0.984313725490196,0.980392156862745,
    0.976470588235294,0.972549019607843,0.968627450980392,0.964705882352941,
    0.96078431372549,0.956862745098039,0.952941176470588,0.949019607843137,
    0.945098039215686,0.941176470588235,0.937254901960784,0.933333333333333,
    0.929411764705882,0.925490196078431,0.925490196078431,0.92156862745098,
    0.917647058823529,0.913725490196078,0.909803921568627,0.909803921568627,
    0.905882352941176,0.901960784313726,0.901960784313726,0.898039215686275,
    0.894117647058824,0.894117647058824,0.890196078431372,0.890196078431372,
    0.886274509803922,0.882352941176471,0.882352941176471,0.87843137254902,
    0.87843137254902,0.874509803921569,0.874509803921569,0.874509803921569,
    0.870588235294118,0.870588235294118,0.866666666666667,0.866666666666667,
    0.866666666666667,0.866666666666667,0.862745098039216,0.862745098039216,
    0.862745098039216,0.862745098039216,0.858823529411765,0.858823529411765,
    0.858823529411765,0.858823529411765,0.858823529411765,0.858823529411765,
    0.858823529411765,0.858823529411765,0.858823529411765,0.858823529411765,
    0.858823529411765,0.858823529411765,0.858823529411765,0.858823529411765,
    0.858823529411765,0.858823529411765,0.858823529411765,0.858823529411765,
    0.858823529411765,0.862745098039216,0.862745098039216,0.862745098039216,
    0.862745098039216,0.866666666666667,0.866666666666667,0.866666666666667,
    0.866666666666667,0.870588235294118,0.870588235294118,0.874509803921569,
    0.874509803921569,0.874509803921569,0.87843137254902,0.87843137254902
  };

  const Rcpp::NumericVector topo_blue = {
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,0.301960784313725,0.286274509803922,
    0.270588235294118,0.258823529411765,0.243137254901961,0.227450980392157,
    0.215686274509804,0.2,0.184313725490196,0.172549019607843,
    0.156862745098039,0.141176470588235,0.129411764705882,0.113725490196078,
    0.101960784313725,0.0862745098039216,0.0705882352941176,0.0588235294117647,
    0.0431372549019608,0.0274509803921569,0.0156862745098039,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0.00784313725490196,0.0156862745098039,0.0235294117647059,0.0313725490196078,
    0.0431372549019608,0.0509803921568627,0.0588235294117647,0.0666666666666667,
    0.0745098039215686,0.0823529411764706,0.0901960784313725,0.0980392156862745,
    0.109803921568627,0.117647058823529,0.125490196078431,0.133333333333333,
    0.141176470588235,0.149019607843137,0.156862745098039,0.164705882352941,
    0.176470588235294,0.184313725490196,0.192156862745098,0.2,
    0.207843137254902,0.215686274509804,0.223529411764706,0.235294117647059,
    0.243137254901961,0.250980392156863,0.258823529411765,0.266666666666667,
    0.274509803921569,0.282352941176471,0.290196078431373,0.301960784313725,
    0.309803921568627,0.317647058823529,0.325490196078431,0.333333333333333,
    0.341176470588235,0.349019607843137,0.356862745098039,0.368627450980392,
    0.376470588235294,0.384313725490196,0.392156862745098,0.4,
    0.407843137254902,0.415686274509804,0.423529411764706,0.435294117647059,
    0.443137254901961,0.450980392156863,0.458823529411765,0.466666666666667,
    0.474509803921569,0.482352941176471,0.490196078431373,0.501960784313725,
    0.509803921568627,0.517647058823529,0.525490196078431,0.533333333333333,
    0.541176470588235,0.549019607843137,0.556862745098039,0.568627450980392,
    0.576470588235294,0.584313725490196,0.592156862745098,0.6,
    0.607843137254902,0.615686274509804,0.623529411764706,0.635294117647059,
    0.643137254901961,0.650980392156863,0.658823529411765,0.666666666666667,
    0.674509803921569,0.682352941176471,0.690196078431373,0.701960784313725
  };

  // const Rcpp::List topo = Rcpp::List::create(
  //   _["r"] = topo_red,
  //   _["g"] = topo_green,
  //   _["b"] = topo_blue
  // );
} // namespace palette
} // namepsace colourvalues

#endif
